package hdm.mi.growbros.models.plant;

import jakarta.persistence.Entity;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.Id;
import jakarta.persistence.ManyToMany;
import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.URL;

import java.util.List;

//careful! months are indexed at 0 (-> 0 = january, 11 = december)

@Data
@AllArgsConstructor
@NoArgsConstructor
@Entity
public class Plant {
    @Id
    @GeneratedValue
    private String id;

    @NotBlank
    private String name;

    private String latinName;

    private String origin;

    private String growthTip;

    @Min(0)
    @Max(11)
    private int plantMonthStart;

    @Min(0)
    @Max(11)
    private int plantMonthEnd;

    @Min(0)
    @Max(11)
    private int harvestMonthStart;

    @Min(0)
    @Max(11)
    private int harvestMonthEnd;

    @ManyToMany
    private List<CropAction> cropActions;

    private SoilType soilType;
    private NutrientDemand nutrientDemand;
    private WaterDemand waterDemand;
    private LightingDemand lightingDemand;

    @URL
    private String imageUrl;

    @Override
    public String toString() {
        return "Plant: {" +
                "id=" + id +
                ", name='" + name + '\'' +
                ", plantMonthStart=" + plantMonthStart +
                ", plantMonthEnd=" + plantMonthEnd +
                ", harvestMonthStart=" + harvestMonthStart +
                ", harvestMonthEnd=" + harvestMonthEnd +
                ", soilType=" + soilType +
                '}';
    }
}
